Learn R Programming

cbbreadr (version 1.0.2)

load_player_box_scores: Load cbb player box score stats

Description

Pull in statistics aggregated by player and game for specified season(s)

This data includes both traditional box score stats (such as points, OREB, AST) as well as more advanced stats (such as USG%, ORTG). For more information on each stat, see the data dictionary dictionary_player_box_scores.

Usage

load_player_box_scores(seasons = most_recent_season())

Value

a dataframe of player box scores.

Arguments

seasons

an integer or vector of integers of seasons to fetch data for. Defaults to the most recent season. Pass in TRUE to fetch all seasons.

See Also

https://john-b-edwards.github.io/cbbreadr/articles/dictionary_player_box_scores.html for a web version of the data dictionary

dictionary_player_box_scores for the data dictionary as bundled within the package

Issues with this data should be filed here: https://github.com/john-b-edwards/cbbd-data/issues

Examples

Run this code
# \donttest{
try({ # avoid cran errors
load_player_box_scores()
})
# }

Run the code above in your browser using DataLab