Learn R Programming

cbbreadr (version 1.0.2)

load_rankings: Load ranking data

Description

Loads information about college basketball rankings, polls, etc.

At present, only the AP Top 25 and Coaches Polls are available from this function. Ranking, first place votes, and over points are available for each week of the season dating back to 1949.

Usage

load_rankings()

Arguments

Value

a dataframe of information about college basketball rankings and polls

See Also

https://john-b-edwards.github.io/cbbreadr/articles/dictionary_rankings.html for a web version of the data dictionary

dictionary_rankings for the data dictionary as bundled within the package

Issues with this data should be filed here: https://github.com/john-b-edwards/cbbd-data/issues

Examples

Run this code
# \donttest{
try({ # avoid cran errors
load_rankings()
})
# }

Run the code above in your browser using DataLab